aind\_data\_schema.imaging package
==================================

Submodules
----------

aind\_data\_schema.imaging.acquisition module
---------------------------------------------

.. automodule:: aind_data_schema.imaging.acquisition
   :members:
   :undoc-members:
   :show-inheritance:

aind\_data\_schema.imaging.instrument module
--------------------------------------------

.. automodule:: aind_data_schema.imaging.instrument
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_data_schema.imaging
   :members:
   :undoc-members:
   :show-inheritance:
